@@ -6,16 +6,18 @@ datazen - Top-level APIs for loading and interacting with variables.
 from typing import List
 
 # internal
+from datazen.code.types import LoadResult
 from datazen.load import DEFAULT_LOADS, LoadedFiles, load_dir
 
 
 def load(
     directories: List[str],
     loads: LoadedFiles = DEFAULT_LOADS,
-) -> dict:
+) -> LoadResult:
     """Load variable data from a list of directories."""
 
     result: dict = {}
+    errors = 0
     for directory in directories:
-        load_dir(directory, result, None, loads)
-    return result
+        errors += int(not load_dir(directory, result, None, loads)[1])
+    return LoadResult(result, errors == 0)
